Theme context for Dioxus
Provides a context provider and hooks for accessing and modifying the theme throughout the component tree.
Re-exports
pub use ThemeProvider_completions::Component::ThemeProvider;pub use ThemeToggle_completions::Component::ThemeToggle;pub use ThemeSelector_completions::Component::ThemeSelector;
Structs
- Theme
Context - Theme context providing access to current theme and theme switching
- Theme
Provider Props - Properties for the
ThemeProvidercomponent.
Functions
- Theme
Provider - Theme provider component
- Theme
Selector - Theme selector dropdown component
- Theme
Toggle - Theme toggle button component
- use_
style - Hook for computing memoized styles based on theme
- use_
theme - Hook to access the theme context